#!/bin/bash
export user=`eval whoami`
basedir=/usr/share/UYAPEditor;

cppath=$basedir/.;
for i in `ls $basedir/*.jar`;do
  cppath=$cppath:$i
done

  echo $cppath;


jdk_version() {
  local result
  local java_cmd
  if [[ -n $(type -p java) ]]
  then
    java_cmd=java
  elif [[ (-n "$JAVA_HOME") && (-x "$JAVA_HOME/bin/java") ]]
  then
    java_cmd="$JAVA_HOME/bin/java"
  fi
  local IFS=$'\n'
  # remove \r for Cygwin
  local lines=$("$java_cmd" -Xms32M -Xmx32M -version 2>&1 | tr '\r' '\n')
  if [[ -z $java_cmd ]]
  then
    result=no_java
  else
    for line in $lines; do
      if [[ (-z $result) && ($line = *"version \""*) ]]
      then
        local ver=$(echo $line | sed -e 's/.*version "\(.*\)"\(.*\)/\1/; 1q')
        # on macOS, sed doesn't support '?'
        if [[ $ver = "1."* ]]
        then
          result=$(echo $ver | sed -e 's/1\.\([0-9]*\)\(.*\)/\1/; 1q')
        else
          result=$(echo $ver | sed -e 's/\([0-9]*\)\(.*\)/\1/; 1q')
        fi
      fi
    done
  fi
  echo "$result"
}

java_ver="$(jdk_version)"

if [[ $java_ver -gt "11" ]]
then
  echo "Java version: $java_ver > 11"
  echo "UYAPEditor not working with this version"

  if [[ -f  "/usr/lib/jvm/oracle-java8-jdk-amd64/bin/java" ]]
  then
    echo "using oracle-java8-jdk-amd64"

    if [ $# -eq 0 ];
    then
      /usr/lib/jvm/oracle-java8-jdk-amd64/bin/java -Xmx200m -cp  $cppath tr.com.havelsan.uyap.system.editor.common.WPAppManager "getNewWPInstance" "EDITOR_TYPE_DOCUMENT"
    else
      /usr/lib/jvm/oracle-java8-jdk-amd64/bin/java -Xmx200m -cp  $cppath tr.com.havelsan.uyap.system.editor.common.WPAppManager "getNewWPInstance" "EDITOR_TYPE_DOCUMENT" "$1"
    fi
    exit;

  elif [[ -f  "/usr/lib/jvm/oracle-java8-jre-amd64/bin/java" ]]
  then
    echo "using oracle-java8-jre-amd64"

    if [ $# -eq 0 ];
      then
        /usr/lib/jvm/oracle-java8-jre-amd64/bin/java -Xmx200m -cp  $cppath tr.com.havelsan.uyap.system.editor.common.WPAppManager "getNewWPInstance" "EDITOR_TYPE_DOCUMENT"
      else
        /usr/lib/jvm/oracle-java8-jre-amd64/bin/java -Xmx200m -cp  $cppath tr.com.havelsan.uyap.system.editor.common.WPAppManager "getNewWPInstance" "EDITOR_TYPE_DOCUMENT" "$1"
    fi
    exit;

  elif [[ -f  "/usr/lib/jvm/java-8-openjdk-amd64/bin/java" ]]
  then
    echo "using java-8-openjdk-amd64"

    if [ $# -eq 0 ];
      then
        /usr/lib/jvm/java-8-openjdk-amd64/bin/java -Xmx200m -cp  $cppath tr.com.havelsan.uyap.system.editor.common.WPAppManager "getNewWPInstance" "EDITOR_TYPE_DOCUMENT"
      else
        /usr/lib/jvm/java-8-openjdk-amd64/bin/java -Xmx200m -cp  $cppath tr.com.havelsan.uyap.system.editor.common.WPAppManager "getNewWPInstance" "EDITOR_TYPE_DOCUMENT" "$1"
    fi
    exit;

  elif [[ -f  "/usr/lib/jvm/java-11-openjdk-amd64/bin/java" ]]
  then
    echo "using java-11-openjdk-amd64"

    if [ $# -eq 0 ];
      then
        /usr/lib/jvm/java-11-openjdk-amd64/bin/java -Xmx200m -cp  $cppath tr.com.havelsan.uyap.system.editor.common.WPAppManager "getNewWPInstance" "EDITOR_TYPE_DOCUMENT"
      else
        /usr/lib/jvm/java-11-openjdk-amd64/bin/java -Xmx200m -cp  $cppath tr.com.havelsan.uyap.system.editor.common.WPAppManager "getNewWPInstance" "EDITOR_TYPE_DOCUMENT" "$1"
    fi
    exit;

  else
    echo "trying to open with default java, $java_ver"

    if [ $# -eq 0 ];
      then
        java -Xmx200m -cp  $cppath tr.com.havelsan.uyap.system.editor.common.WPAppManager "getNewWPInstance" "EDITOR_TYPE_DOCUMENT"
      else
        java -Xmx200m -cp  $cppath tr.com.havelsan.uyap.system.editor.common.WPAppManager "getNewWPInstance" "EDITOR_TYPE_DOCUMENT" "$1"
    fi
    exit;

  fi

else
  echo "Java version: $java_ver"
  if [ $# -eq 0 ];
    then
      java -Xmx200m -cp  $cppath tr.com.havelsan.uyap.system.editor.common.WPAppManager "getNewWPInstance" "EDITOR_TYPE_DOCUMENT"
    else
      java -Xmx200m -cp  $cppath tr.com.havelsan.uyap.system.editor.common.WPAppManager "getNewWPInstance" "EDITOR_TYPE_DOCUMENT" "$1"
  fi
  exit;
fi
